@@ -1,13 +1,6 @@
 # noqa: F401
 
+from . import conditionals, multioutput, sample_conditionals
 from .dispatch import conditional, sample_conditional
-
-from . import conditionals
-from . import sample_conditionals
-
-from . import multioutput
-
-
-from .util import base_conditional
-
 from .uncertain_conditionals import uncertain_conditional
+from .util import base_conditional
