@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import Callable, Sequence, Optional
+from typing import Callable, Optional, Sequence
 
 import tensorflow as tf
 
