@@ -1,3 +1,3 @@
 from .base import GaussianQuadrature
+from .deprecated import hermgauss, mvhermgauss, mvnquad, ndiag_mc, ndiagquad
 from .gauss_hermite import NDiagGHQuadrature
-from .deprecated import hermgauss, mvhermgauss, mvnquad, ndiagquad, ndiag_mc
