@@ -2,14 +2,14 @@ import numpy as np
 import pytest
 import tensorflow as tf
 import tensorflow_probability as tfp
+from tensorflow_probability.python.bijectors import Exp
+from tensorflow_probability.python.distributions import Gamma, Uniform
 
 import gpflow
 from gpflow import default_float
 from gpflow.base import PriorOn
 from gpflow.config import set_default_float
 from gpflow.utilities import to_default_float
-from tensorflow_probability.python.bijectors import Exp
-from tensorflow_probability.python.distributions import Uniform, Gamma
 
 np.random.seed(1)
 
